@@ -1,5 +1,5 @@
 
--- libquvi-scripts v0.4.7
+-- libquvi-scripts v0.4.9
 -- Copyright (C) 2012  quvi project
 --
 -- This file is part of libquvi-scripts <http://quvi.sourceforge.net/>.
@@ -55,8 +55,9 @@ end
 function HaOgg.check_external_content(self)
     local p = quvi.fetch(self.page_url)
 
-    local a = p:match('<div id="space4para" class="post%-type%-gvideos">(.-)</div>')
-                or error("no match: article")
+    local m = '<div .- id="space4para" class="post%-type%-gvideos">'
+              ..'.-<script (.-)</script>'
+    local a = p:match(m) or error("no match: article")
 
     -- Self-hosted, and they use YouTube
     -- http://www.101greatgoals.com/gvideos/golazo-wanchope-abila-sarmiento-junin-v-merlo-2/
